@@ -21,9 +21,9 @@
 #' @examples
 #'
 #' dbc <- nodbi::src_sqlite(
-#'     dbname = system.file("extdata", "demo.sqlite", package = "ctrdata"),
-#'     collection = "my_trials",
-#'    RSQLite::SQLITE_RO)
+#'   dbname = system.file("extdata", "demo.sqlite", package = "ctrdata"),
+#'   collection = "my_trials",
+#'   flags = RSQLite::SQLITE_RO)
 #'
 #' dbQueryHistory(con = dbc)
 #'
@@ -81,7 +81,7 @@ dbQueryHistory <- function(con, verbose = FALSE) {
   }
 
   # return
-  if (any("tibble" == .packages())) return(tibble::as_tibble(hist))
-  return(hist)
+  return(dfOrTibble(hist))
+
 }
 # end ctrQueryHistoryInDb
