@@ -58,6 +58,8 @@ typeVars <- list(
   "history.documentSection.largeDocumentModule.largeDocs.date"            = "ctrDate",
   "history.documentSection.largeDocumentModule.largeDocs.uploadDate"      = "ctrDate",
   "history.history_version.version_date"                                  = "ctrDate",
+  "history.protocolSection.eligibilityModule.maximumAge"                  = "ctrDifftime",
+  "history.protocolSection.eligibilityModule.minimumAge"                  = "ctrDifftime",
   "history.protocolSection.statusModule.completionDateStruct.date"        = "ctrDate",
   "history.protocolSection.statusModule.dispFirstPostDateStruct.date"     = "ctrDate",
   "history.protocolSection.statusModule.dispFirstSubmitDate"              = "ctrDate",
@@ -73,6 +75,8 @@ typeVars <- list(
   "history.protocolSection.statusModule.studyFirstPostDateStruct.date"    = "ctrDate",
   "history.protocolSection.statusModule.studyFirstSubmitDate"             = "ctrDate",
   "history.protocolSection.statusModule.studyFirstSubmitQcDate"           = "ctrDate",
+  "protocolSection.eligibilityModule.maximumAge"                  = "ctrDifftime",
+  "protocolSection.eligibilityModule.minimumAge"                  = "ctrDifftime",
   "protocolSection.statusModule.completionDateStruct.date"        = "ctrDate",
   "protocolSection.statusModule.dispFirstPostDateStruct.date"     = "ctrDate",
   "protocolSection.statusModule.dispFirstSubmitDate"              = "ctrDate",
@@ -92,6 +96,7 @@ typeVars <- list(
   # - ISRCTN
   "participants.recruitmentStart" = "ctrDateTime",
   "participants.recruitmentEnd"   = "ctrDateTime",
+  "results.intentToPublish"       = "ctrDateTime",
   "trialDesign.overallStartDate"  = "ctrDateTime",
   "trialDesign.overallEndDate"    = "ctrDateTime",
   #
@@ -161,12 +166,13 @@ typeVars <- list(
   "authorizedApplication.authorizedPartsII.mscInfo.trialRestartDate" = "ctrDate",
   "authorizedApplication.memberStatesConcerned.firstDecisionDate" = "ctrDate",
   "authorizedApplication.memberStatesConcerned.lastDecisionDate" = "ctrDate",
-  "correctiveMeasures.correctiveMeasureNotifications.unexpectedEventNotifications.submissionDate" = "ctrDate",
   "correctiveMeasures.correctiveMeasureNotifications.seriousBreachNotifications.submissionDate" = "ctrDate",
+  "correctiveMeasures.correctiveMeasureNotifications.unexpectedEventNotifications.submissionDate" = "ctrDate",
+  "correctiveMeasures.correctiveMeasureNotifications.urgentSafetyNotifications.submissionDate" = "ctrDate",
   "correctiveMeasures.revertedDate" = "ctrDate",
   "correctiveMeasures.sponsorActionRequiredByDate" = "ctrDate",
   "correctiveMeasures.sponsorSubmitDate" = "ctrDate",
-  # "decisionDate" is a composite string
+  # "decisionDate" cannot be types, is string concatenating dates
   "events.seriousBreaches.awareDate" = "ctrDate",
   "events.seriousBreaches.breachDate" = "ctrDate",
   "events.seriousBreaches.submissionDate" = "ctrDate",
@@ -175,31 +181,18 @@ typeVars <- list(
   "events.temporaryHaltList.submitDate" = "ctrDate",
   "events.trialEvents.events.date" = "ctrDate",
   "events.trialGlobalEndDate" = "ctrDate",
+  "events.unexpectedEvents.awareDate" = "ctrDate",
+  "events.unexpectedEvents.eventDate" = "ctrDate",
+  "events.unexpectedEvents.submissionDate" = "ctrDate",
   "events.urgentSafetyMeasures.eventDate" = "ctrDate",
   "events.urgentSafetyMeasures.submissionDate" = "ctrDate",
   "publishDate" = "ctrDate",
   "results.clinicalStudyReports.procedureOutcomeDate" = "ctrDate",
   "results.clinicalStudyReports.submitDate" = "ctrDate",
   "results.laypersonResults.submissionDate" = "ctrDate",
-  "results.summaryResults.submissionDate" = "ctrDate",
-  "authorizedApplication.authorizedPartI.productRoleGroupInfos.products.part1MedicinalProductRoleMscInfos.memberStateConcernedInfo.activeTrialPeriod.trialEndDate" = "ctrDate",
-  "authorizedApplication.authorizedPartI.productRoleGroupInfos.products.part1MedicinalProductRoleMscInfos.memberStateConcernedInfo.trialPeriod.trialEndDate" = "ctrDate",
-  "authorizedApplication.authorizedPartI.products.part1MedicinalProductRoleMscInfos.memberStateConcernedInfo.activeTrialPeriod.trialEndDate" = "ctrDate",
-  "correctiveMeasures.revertedDate" = "ctrDate",
-  "correctiveMeasures.sponsorSubmitDate" = "ctrDate",
-  "events.seriousBreaches.submissionDate" = "ctrDate",
-  "events.temporaryHaltList.plannedRestartDate" = "ctrDate",
-  "events.trialGlobalEndDate" = "ctrDate",
-  "events.unexpectedEvents.eventDate" = "ctrDate",
-  "results.summaryResults.submissionDate"  = "ctrDate",
-  "authorizedApplication.authorizedPartI.products.part1MedicinalProductRoleMscInfos.memberStateConcernedInfo.trialPeriod.trialEndDate" = "ctrDate",
-  "authorizedApplication.authorizedPartsII.mscInfo.trialRestartDate" = "ctrDate",
-  "correctiveMeasures.sponsorActionRequiredByDate" = "ctrDate",
-  "events.seriousBreaches.breachDate" = "ctrDate",
-  "events.unexpectedEvents.awareDate" = "ctrDate",
-  "events.unexpectedEvents.submissionDate" = "ctrDate",
-  "results.laypersonResults.submissionDate" = "ctrDate",
   "results.laypersonResults.withdrawDate" = "ctrDate",
+  "results.summaryResults.submissionDate" = "ctrDate",
+  "startDateEU" = "ctrDate",
   #
   # ctis until 2024-06-17
   "applications.ctMSCs.activeTrialPeriod.fromDate" = "ctrDate",
@@ -468,9 +461,11 @@ typeVars <- list(
   "e816_cross_over"     = "ctrYesNo",
   "e817_other"          = "ctrYesNo",
   "e822_placebo"        = "ctrYesNo",
+  "e823_other"          = "ctrYesNo",
   #
   "e83_the_trial_involves_single_site_in_the_member_state_concerned"    = "ctrYesNo",
   "e83_will_this_trial_be_conducted_at_a_single_site_globally"          = "ctrYesNo",
+  "e83single_site_trial"                                                = "ctrYesNo", # 2025-02-10
   "e83_single_site_trial"                                               = "ctrYesNo", # 2023-10-05
   "e84_multiple_sites_in_member_state"                                  = "ctrYesNo", # 2023-10-05
   "e84_will_this_trial_be_conducted_at_multiple_sites_globally"         = "ctrYesNo",
@@ -503,6 +498,7 @@ typeVars <- list(
   "f335_emergency_situation" = "ctrYesNo",
   "f336_subjects_incapable_of_giving_consent_personally" = "ctrYesNo",
   #
+  "endPoints.endPoint.countable"               = "ctrFalseTrue",
   "trialInformation.analysisForPrimaryCompletion" = "ctrFalseTrue",
   "trialInformation.partOfPIP"                 = "ctrFalseTrue",
   "trialInformation.art45Related"              = "ctrFalseTrue",
